ipsec whack --impair suppress_retransmits
ipsec auto --up ipv4-psk-ikev2-transport
echo done
